@@ -1,8 +1,11 @@
 import functools
-from pathlib import Path
+from transparentpath import Path
 import pandas as pd
 import numpy as np
 import numpy.random
+import dotenv
+import argparse
+
 
 # from dask.distributed import Client
 # from dask import distributed as dst
@@ -39,6 +42,15 @@ import numpy.random
 # ddf = ddf.reset_index()
 # ddf.index = ind
 
+Path.set_global_fs("gcs", bucket="nmf_experiments_dev", token="../cred_gcs.json")
+dotenv.load_dotenv()
+
+
+def collect_optimal_k_outputs() -> pd.DataFrame:
+
+    outputpath = Path("screeplots")
+    return pd.concat([afile.read(index_col=0) for afile in outputpath.glob("*.csv")], axis='index')
+
 
 def collect_features_mean_values(data_path: Path, **kwargs) -> pd.DataFrame:
     # exclusion_list=None, period="", mode: str = "mean")
@@ -118,4 +130,15 @@ def collect_features_mean_values(data_path: Path, **kwargs) -> pd.DataFrame:
 
 
 if __name__ == "__main__":
+
+    parser = argparse.ArgumentParser(
+        description="Output files collector",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+    )
+    parser.add_argument("-o", "--output", type=str, default="output.csv", help="Output localization")
+    args = parser.parse_args()
+    output = Path(args.output)
+
+    df_outputs = collect_optimal_k_outputs()
+    output.write(df_outputs)
     pass
