@@ -96,7 +96,7 @@ def normalized_entropy(mat, nbins=3) -> float:
         return scipy.stats.entropy(freqs.frequency) / math.log(nbins)
 
 
-def relative_entropy_by_cluster(mat, lineclusters, colclusters, nbins=10) :
+def relative_entropy_by_cluster(mat, lineclusters, colclusters, nbins=10):
     assert nbins > 0
     nl, nc = mat.shape
     assert nl == len(lineclusters)
@@ -647,7 +647,7 @@ def plot_values(mat, xticklabels=False, yticklabels=True, path=None):
     plt.close("all")
 
 
-def generate_random_correl_matrix(size: int, corr_max: float):
+def generate_random_correl_matrix(size: int, corr_max: float) -> pd.DataFrame:
     """
 
      generate_random_correl_matrix:
@@ -780,17 +780,13 @@ def generate_integer_partition(ntot: int, nbpart: int, nmin: int = 1):
     return res
 
 
-def generate_clusterized_vectors(veclen: int,
-                                 nclusters: int,
-                                 nbvect: int,
-                                 clusterminsize: int,
-                                 max_inter_corr: float,
-                                 min_intra_corr: float,
-                                 random_norms: bool = True) -> pd.DataFrame:
+def generate_clusterized_vectors(vsize: int, nbvect: int, nclusters: int,
+                                 clusterminsize: int, max_inter_corr: float,
+                                 min_intra_corr: float, random_norms: bool = True) -> pd.DataFrame:
 
     clustersizes = generate_integer_partition(ntot=nbvect, nbpart=nclusters, nmin=clusterminsize)
-    centroids = generate_clusters_centroids(ndim=veclen, max_corr=max_inter_corr)
-    df_res = pd.DataFrame(index=range(veclen))
+    centroids = generate_clusters_centroids(ndim=vsize, max_corr=max_inter_corr)
+    df_res = pd.DataFrame(index=range(vsize))
     # factors = np.random.exponential(size=nclusters) if random_norms else np.zeros(shape=nclusters)
     factors = np.random.lognormal(mean=0, sigma=1, size=nclusters)
     row_shift = 0
