@@ -8,8 +8,12 @@ from adlinear import nmfmodel as nmf
 from randomgenerators import randomgenerators as rng
 import dotenv
 
-Path.set_global_fs("gcs", bucket="nmf_experiments_dev", token="cred_gcs.json")
-dotenv.load_dotenv()
+use_gcs = False
+if use_gcs:
+    Path.set_global_fs("gcs", bucket="nmf_experiments_dev", token="cred_gcs.json")
+    dotenv.load_dotenv()
+else:
+    Path.set_global_fs("local")
 
 if __name__ == "__main__":
 
@@ -24,19 +28,23 @@ if __name__ == "__main__":
     parser.add_argument("-e", "--epsilon", type=float, default=0.10, help="Epsilon")
     parser.add_argument("-m", "--ncmin", type=int, default=2, help="Minimum number of components")
     parser.add_argument("-M", "--ncmax", type=int, default=45, help="Maximum number of components")
-    parser.add_argument("-W", "--wclust_f", type=float, default=1.0, help="#W clusters to #H clusters ratio")
+    parser.add_argument("-W", "--w_avg", type=int, default=2, help="Average size of W clusters")
+    parser.add_argument("-H", "--h_avg", type=int, default=2, help="Average size of H clusters")
+    parser.add_argument("-a", "--wclust_f", type=float, default=1.0, help="#W clusters to #H clusters ratio")
     parser.add_argument("-i", "--icorrmin", type=float, default=0.3, help="Minimum intra-cluster correlation")
     parser.add_argument("-I", "--icorrmax", type=float, default=0.95, help="Maximum intra-cluster correlation")
     parser.add_argument("-x", "--xcorrmin", type=float, default=0.0, help="Minimum extra-cluster correlation")
     parser.add_argument("-X", "--xcorrmax", type=float, default=0.3, help="Maximum extra-cluster correlation")
     parser.add_argument("-p", "--do_entropy", type=bool, default=False, help="Optional entropy calculation")
     args = parser.parse_args()
-    output = Path(args.output)
+    outputpath = Path(args.output)
     epsilon = args.epsilon
     ncmin = args.ncmin
     ncmax = args.ncmax
     nruns = args.runs
-    wcmax = args.wclust_f
+    wclust_f = args.wclust_f
+    w_avg = args.w_avg
+    h_avg = args.h_avg
     do_ent = args.do_entropy
     icorrmin = args.icorrmin
     icorrmax = args.icorrmax
@@ -44,7 +52,7 @@ if __name__ == "__main__":
     xcorrmax = args.xcorrmax
     writefreq = args.writefreq
 
-    print(f"Will execute {nruns} run(s), will write output(s) in {output} every {writefreq} iteration(s)")
+    print(f"Will execute {nruns} run(s), will write output(s) in {outputpath} every {writefreq} iteration(s)")
 
     rand_norms = True
     df_mini_scree_plots = pd.DataFrame(index=[], columns=[])
@@ -52,24 +60,29 @@ if __name__ == "__main__":
         nb_clusters = np.random.randint(low=ncmin, high=ncmax)
         intra_corr = np.random.uniform(low=icorrmin, high=icorrmax)
         xtra_corr = np.random.uniform(low=xcorrmin, high=xcorrmax)
-        h_size = np.random.randint(low=100, high=200)
+        h_size = h_avg * nb_clusters
         w_size = np.random.randint(low=100, high=200)
         eps = np.random.uniform(low=0.0, high=epsilon)
-        wclust_factor = np.random.uniform(0.0, wcmax)
+        wclust_factor = np.random.uniform(0.0, wclust_f)
 
         generated_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
                                                                h_icorr_min=icorrmin, h_icorr_max=xcorrmax,
                                                                w_icorr_min=xcorrmin, w_icorr_max=icorrmax,
-                                                               epsilon=eps, random_norms=rand_norms,
+                                                               random_norms=rand_norms, epsilon=eps,
                                                                wclust_factor=wclust_factor)
         rnstr = "RandNorms" if rand_norms else "ConstNorms"
 
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax, do_entropies=do_ent)
-        df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax, known_ncomp=nb_clusters,
+                                                do_entropies=do_ent)
+        df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_examples=df_mini_scree_plots,
+                                                                      scree_plot=df_scree_plot,
+                                                                      known_ncomp=nb_clusters,
+                                                                      ncomp_margin=1)
 
         if itrial % writefreq == 0 or itrial == nruns-1:
-            print(f"Saving iteration {itrial} in {output}")
+            print(f"Saving iteration {itrial} in {outputpath}")
             assert not df_mini_scree_plots.empty
-            output.write(df_mini_scree_plots)
-            assert output.isfile()
-            assert not output.read().empty
+            outputpath.write(df_mini_scree_plots)
+            df_scree_plot.to_csv(args.output.split(".csv")[0]+f"_scp{itrial}_nc{nb_clusters}.csv")
+            assert outputpath.isfile()
+            assert not outputpath.read().empty
