@@ -19,6 +19,8 @@ dotenv.load_dotenv()
 
 
 if __name__ == "__main__":
+    # Defining paths
+    # ***********************************************************************************
 
     root_path = root_path.get_root_path()
 
@@ -33,6 +35,7 @@ if __name__ == "__main__":
 
     res_path = imputation_paper_path / os.getenv("results_subpath")
 
+    # Experiments on Brunet dataset
     if os.getenv("imp_do_brunet", "False").lower() == "true":
         df_brunet = pd.read_csv(data_path / os.getenv("brunet_filename"))
         df_brunet_groups = pd.read_csv(data_path / os.getenv("brunet_grp_filename"))
@@ -40,6 +43,7 @@ if __name__ == "__main__":
         ngrps_brunet = 3
         ncomp_brunet = 4
         # la colonne d'attribution des groupes
+        # Brunet dataset has 3 groups, the group ALL_B being sometimes divided in two subgroups
         if ngrps_brunet == 4:
             df_brunet_priors = df_brunet.replace({"Group": {"ALL_B_1": 1,
                                                             "ALL_B_2": 2,
@@ -59,6 +63,12 @@ if __name__ == "__main__":
         nmf_log_brunet = nmf.NmfModel(mat=df_log_brunet, name="log_brunet",
                                       ncomp=ncomp_brunet, regularization="components", leverage="robust", max_iter=200)
 
+        if os.getenv("imp_do_brunet_screeplot", "False").lower() == "true":
+            ncmin = 1
+            ncmax = 15
+            df_scree_plot = nmf.generate_scree_plot(df_log_brunet, ncmin=ncmin, ncmax=ncmax, do_entropies=False)
+            df_scree_plot.to_csv(res_path/"logbrunet_screeplot.csv")
+
         if os.getenv("imp_do_brunet_test_prop", "False").lower() == "true":
             # df_res_brunet = tst.test_missing_proportion(df_log_brunet, ncomp=ncomp_brunet,
             #                                             name="log_brunet", grp_priors=df_brunet_priors,
@@ -109,6 +119,15 @@ if __name__ == "__main__":
 
             imp_tester.output_results(out_data_path)
 
+    # Experiments on Epithor dataset
+    if os.getenv("imp_do_epithor", "False").lower() == "true":
+        df_epithor = pd.read_csv(data_path / os.getenv("epithor_filename"))
+        df_epithor.drop(["Ref_Sujet", "Centre", "N°INSEE", "Code", "Suivi"], axis='columns', inplace=True)
+        ncmin = 1
+        ncmax = 15
+        df_scree_plot = nmf.generate_scree_plot(df_epithor, ncmin=ncmin, ncmax=ncmax, do_entropies=False)
+        df_scree_plot.to_csv(res_path/"df_epithor.csv")
+
     if os.getenv("imp_do_random", "False").lower() == "true":
 
         standard_noise = rng.RandomVariable(np.random.normal, 1, 0.05)
@@ -243,8 +262,8 @@ if __name__ == "__main__":
         eps = 0.10
         # noinspection PyTupleAssignmentBalance
         gen_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
-                                                         h_icorr_min=min_corr, h_icorr_max=max_corr, epsilon=eps,
-                                                         random_norms=rnd_norms)
+                                                         h_icorr_min=min_corr, h_icorr_max=max_corr,
+                                                         random_norms=rnd_norms, epsilon=eps)
         imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
                                     params={"ncomp": 3,
                                             "nblocks": 1,
@@ -300,8 +319,8 @@ if __name__ == "__main__":
                                [[0, 0], [1, 2]]]
         gen_m, gen_w, gen_h, gen_noise = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
                                                                          n_obs=w_size, h_icorr_min=min_corr,
-                                                                         h_icorr_max=max_corr, epsilon=eps,
-                                                                         random_norms=random_norms,
+                                                                         h_icorr_max=max_corr,
+                                                                         random_norms=random_norms, epsilon=eps,
                                                                          wclust_factor=wclust_factor)
         for censor_indices in censor_indices_list:
 
@@ -358,8 +377,8 @@ if __name__ == "__main__":
                           f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_rate}.csv"
                 gen_M, gen_w, gen_h, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
                                                                          n_obs=w_size, h_icorr_min=min_corr,
-                                                                         h_icorr_max=max_corr, epsilon=eps,
-                                                                         random_norms=random_norms)
+                                                                         h_icorr_max=max_corr,
+                                                                         random_norms=random_norms, epsilon=eps)
 
             utl.censor_data(mat=gen_M, p=censor_rate, inplace=True)
             gen_M.to_csv(res_path / "random_nmf" / wh_name,
